@@ -10,8 +10,7 @@ import pandas as pd
 import matplotlib.pyplot as plt
 import torch
 tf.io.gfile = tb.compat.tensorflow_stub.io.gfile
-from eli5.permutation_importance import get_score_importances
-from captum.attr import IntegratedGradients
+from captum.attr import IntegratedGradients, FeaturePermutation
 from captum.attr import visualization as viz
 from captum.attr import GuidedGradCam, LayerGradCam, LayerAttribution
 
@@ -127,18 +126,23 @@ class ComprehensibilityAnalysis:
 
     def permutation_importance(self, feature_names, plot=False, title='Average Feature Importances',
                                axis_title='Features'):
+        """
+        Only PyTorch
+        :param feature_names:
+        :param plot:
+        :param title:
+        :param axis_title:
+        :return:
+        """
 
-        def score(X, y):
-            X = self.interface.from_numpy(X)
-            y_pred = self.interface.predict(X)
-            y_pred = self.interface.to_numpy(y_pred)
-            metric = self.metric(y, y_pred)
-            return metric
+        def score(inputs, target):
+            y_pred = self.model(inputs)
+            return y_pred
 
-        x_test = self.interface.to_numpy(self.x_test)
-        y_test = self.interface.to_numpy(self.y_test)
-        base_score, score_decreases = get_score_importances(score, X=x_test, y=y_test)
-        feature_importances = np.mean(score_decreases, axis=0)
+        y_test = self.interface.from_numpy(self.y_test, dtype=torch.int64)
+        feature_perm = FeaturePermutation(score)
+        attr = feature_perm.attribute(inputs=self.x_test, target=y_test, additional_forward_args=y_test)
+        feature_importances = np.mean(attr.detach().numpy(), axis=0)
 
         for i in range(len(feature_names)):
             print(feature_names[i], ": ", '%.3f' % (feature_importances[i]))
