@@ -18,4 +18,5 @@ class FunctionalityAnalysis:
         disp.plot()
         plt.show()
 
-
+    def compute_metric(self):
+        return self.interface.metric(self.y_test, self.y_pred)
