@@ -6,8 +6,6 @@ import matplotlib.pyplot as plt
 
 
 from models import *
-from task import ImitationLearning
-from dataloader import ImageActionDataModule
 from FunctionalityAnalysis import FunctionalityAnalysis
 from ComprehensibilityAnalysis import ComprehensibilityAnalysis
 from RobustnessAnalysis import RobustnessAnalysis
@@ -19,7 +17,7 @@ import torch.optim as optim
 import torchvision
 import torchvision.models as models
 from torchvision import datasets, transforms as T
-from captum.attr import GuidedGradCam, LayerGradCam, LayerAttribution, Lime
+from captum.attr import GuidedGradCam, LayerGradCam, LayerAttribution, Lime, FeaturePermutation
 
 # PyTorch adversarial-robustness
 from art.attacks.evasion import FastGradientMethod
@@ -31,6 +29,7 @@ from art.metrics import empirical_robustness
 from sklearn.datasets import load_iris
 from sklearn.linear_model import LinearRegression, LogisticRegression
 from sklearn.model_selection import train_test_split
+from sklearn.neural_network import MLPClassifier
 
 
 # Tensorflow
@@ -38,48 +37,16 @@ import tensorflow as tf
 
 
 def main(params):
-    # pytorch()
     # pytorch_titanic()
-    pytorch_cifar()
+    # pytorch_cifar()
     # pytorch_imagenet()
     # scikit()
     # tensorflow()
-
-
-def pytorch():
-    checkpoint = 'models/version_23/checkpoints/epoch=49.ckpt'
-    imgs_dir = 'models/h5py_num_imgs_10000_batch_size_1000'
-    model = CNN(n_actions=4)
-    task = ImitationLearning.load_from_checkpoint(checkpoint, max_epochs=10, model=model)
-    datamodule = ImageActionDataModule(imgs_dir, 1000, perc_val=0)
-    datamodule.setup()
-    trainloader = datamodule.train_dataloader()
-    x_train, y_train, indices = next(iter(trainloader))
-    x_test, y_test, indices = next(iter(trainloader))
-    interface = PyTorchInterface(task.model, x_test, y_test, metric_name='accuracy')
-    analysis = ComprehensibilityAnalysis(interface)
-    # analysis.visualize_pca(function=task.model, n_components=3, vis3d=True)
-    # analysis.vis_pca_tb(function=task.model, num_channels=3)
-
-    # art
-    robustness = RobustnessAnalysis(interface)
-    criterion = nn.CrossEntropyLoss()
-    robustness.fast_gradient_sign_method(num_classes=4, criterion=criterion, visualize=True)
+    tensorflow_titanic()
 
 
 def pytorch_titanic():
-    titanic_data = pd.read_csv('models/train.csv')
-
-    titanic_data.columns = titanic_data.columns.str.lower()
-
-    titanic_data = pd.concat([titanic_data,
-                              pd.get_dummies(titanic_data['sex']),
-                              pd.get_dummies(titanic_data['embarked'], prefix="embark"),
-                              pd.get_dummies(titanic_data['pclass'], prefix="class")], axis=1)
-    titanic_data["age"] = titanic_data["age"].fillna(titanic_data["age"].mean())
-    titanic_data["fare"] = titanic_data["fare"].fillna(titanic_data["fare"].mean())
-    titanic_data = titanic_data.drop(['name', 'ticket', 'cabin', 'sex', 'embarked', 'pclass', 'passengerid'], axis=1)
-
+    titanic_data = pd.read_csv('titanic.csv', index_col=0)
     # Set random seed for reproducibility.
     np.random.seed(131254)
 
@@ -90,23 +57,25 @@ def pytorch_titanic():
     feature_names = list(titanic_data.columns)
 
     # Separate training and test sets using
-    train_indices = np.random.choice(len(labels), int(0.7 * len(labels)), replace=False)
-    test_indices = list(set(range(len(labels))) - set(train_indices))
-    train_features = titanic_data.iloc[train_indices]
-    train_labels = labels[train_indices]
-    test_features = data[test_indices]
+    test_indices = list(np.random.choice(len(labels), int(0.3 * len(labels)), replace=False))
+    x_test = data[test_indices]
     y_test = labels[test_indices]
+
+    # Load model
     net = TitanicSimpleNNModel()
     net.load_state_dict(torch.load('models/titanic_model.pt'))
-    x_test = torch.as_tensor(test_features, dtype=torch.float)
-    y_test = y_test.to_numpy()
-    # print(p_percent_score(sensitive_column='male', positive_target=1)(net, train_features)) # Maybe Fairness?
 
+    # Transform to correct format
+    x_test = torch.as_tensor(x_test, dtype=torch.float)
+    y_test = y_test.to_numpy()
     # Analysis
     interface = PyTorchInterface(net, x_test, y_test, metric_name='accuracy')
-    analysis = ComprehensibilityAnalysis(interface)
+    functionality = FunctionalityAnalysis(interface)
+    # functionality.plot_confusion_matrix()
+    print(functionality.compute_metric())
+    # analysis = ComprehensibilityAnalysis(interface)
 
-    # analysis.permutation_importance(feature_names, plot=True)
+    #analysis.permutation_importance(feature_names, plot=True)
     # analysis.vis_feature_importance(feature_names=feature_names, class_label=1)
     # analysis.plot_single_attribute(num=1, feature_names=feature_names, class_label=1)
 
@@ -155,38 +124,22 @@ def pytorch_imagenet():
 
 
 def scikit():
-    # shap.initjs()
-
-    # Iris dataset
-    iris = load_iris()
-    X_train, X_test, Y_train, Y_test = train_test_split(iris, test_size=0.2, random_state=0)
-
     # Titanic dataset
-    titanic_data = pd.read_csv('models/train.csv')
-    titanic_data.columns = titanic_data.columns.str.lower()
-    titanic_data = pd.concat([titanic_data,
-                              pd.get_dummies(titanic_data['sex']),
-                              pd.get_dummies(titanic_data['embarked'], prefix="embark"),
-                              pd.get_dummies(titanic_data['pclass'], prefix="class")], axis=1)
-    titanic_data["age"] = titanic_data["age"].fillna(titanic_data["age"].mean())
-    titanic_data["fare"] = titanic_data["fare"].fillna(titanic_data["fare"].mean())
-    titanic_data = titanic_data.drop(['name', 'ticket', 'cabin', 'sex', 'embarked', 'pclass', 'passengerid'], axis=1)
+    titanic_data = pd.read_csv('titanic.csv', index_col=0)
     labels = titanic_data["survived"]
-    train_indices = np.random.choice(len(labels), int(0.7 * len(labels)), replace=False)
-    test_indices = list(set(range(len(labels))) - set(train_indices))
-    train_features = titanic_data.iloc[train_indices]
-    train_labels = labels[train_indices]
-    test_features = titanic_data.iloc[test_indices]
-    test_labels = labels[test_indices]
+    titanic_data = titanic_data.drop(['survived'], axis=1)
+    x_train, x_test, y_train, y_test = train_test_split(titanic_data, labels, random_state=1, train_size=0.8)
 
-    pd.set_option('display.max_columns', None)
-
-    model = LogisticRegression()
-    model.fit(train_features, train_labels)
+    model = MLPClassifier(hidden_layer_sizes=(5, 2), random_state=3, max_iter=1000)
+    # model = LogisticRegression()
+    model.fit(x_train.to_numpy(), y_train.to_numpy())
 
 
-    # interface = SciPyInterface(model, X_test, Y_test, metric_name='accuracy')
-    # analysis = ComprehensibilityAnalysis(interface)
+    interface = SciPyInterface(model, x_test.to_numpy(), y_test.to_numpy(), metric_name='accuracy')
+    analysis = ComprehensibilityAnalysis(interface)
+    functionality = FunctionalityAnalysis(interface)
+    print(functionality.compute_metric())
+    functionality.plot_confusion_matrix()
     # analysis.visualize_pca(dataset=True, n_components=3, vis3d=True)
     # analysis.vis_pca_tb(dataset=True, vis_imgs_tb=False)
     # analysis.partial_plot(feature_names=['0', '1', '2', '3'])
@@ -226,6 +179,27 @@ def tensorflow():
     analysis.vis_pca_tb(function=function, vis_imgs_tb=False)
 
 
+def tensorflow_titanic():
+    titanic_data = pd.read_csv('titanic.csv', index_col=0)
+    labels = titanic_data["survived"]
+    titanic_data = titanic_data.drop(['survived'], axis=1)
+    x_train, x_test, y_train, y_test = train_test_split(titanic_data, labels, random_state=1, train_size=0.8)
+    model = tf.keras.models.Sequential([
+          tf.keras.layers.Dense(128, activation='relu'),
+          tf.keras.layers.Dropout(0.2),
+          tf.keras.layers.Dense(10)
+        ])
+    loss_fn = tf.keras.losses.SparseCategoricalCrossentropy(from_logits=True)
+    model.compile(optimizer='adam',
+                      loss=loss_fn,
+                      metrics=['accuracy'])
+    model.fit(x_train, y_train, epochs=5)
+    x_test = tf.convert_to_tensor(x_test)
+    interface = TensorFlowInterface(model, x_test, y_test.to_numpy(), metric_name='accuracy')
+    functionality = FunctionalityAnalysis(interface)
+    print(f'accuracy: {functionality.compute_metric()}')
+    functionality.plot_confusion_matrix()
+
 if __name__ == '__main__':
     parser = argparse.ArgumentParser(description='analysis of model')
 
